import { Component, Input, NgModule } from '@angular/core';
import { DomSanitizer } from '@angular/platform-browser';
import { CommonModule } from '@angular/common';

class HybridAvatarComponent {
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
        this.defaultColors = [
            '#468547',
            '#FF3B30',
            '#eb7191',
            '#0050D6',
            '#3670b2',
            '#5856D6',
            '#FF2D55' // Pink
        ];
        this.defaultAvatarImage = `data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAGAAAABgCAAAAADH8y
                jkAAAABGdBTUEAALGPC/xhBQAAAAlwSFlzAAAOwwAADsMBx2+oZAAAABh0RVh0U29
                mdHdhcmUAcGFpbnQubmV0IDQuMS42/U4J6AAAAzJJREFUaN7t2OtvEkEQAPD+6Wy5
                4yHQejEVaYumQtNXFGMr+EJ8QPqwjdYLpYaGPi1KJZVQQ+n1WNHG1Cvs7tzs4QdlP
                pP5sXd7szM74OpxDPSBPvDPAR6fT+0VEJxe2akZrVaztvUm5nMaUOZK5/SPaOYniI
                MASVRpRxzEiFPAyC7tFq18wBGAPDyjjDiZcAAgOcoO84E0wM0PEURAlvLDvC8H3Gs
                JANockwGGGlQYRyoeIEUKiBweuAvJT41hLEB2QQB9iwXGYPlp048EVoAAXcAB7joU
                KOGAUWh+euZFAfNggI6jgFU4kEQBBTiQRQFHcED/T4EDOLCGAnQ4kEYBaTgwhQJi4
                PxmEAVcO4cCVYKrpttQYAlZrhNQIIIEPCew/HvoM/kJDIijAU8Nkn9Xoi+aA+Q/j0
                gA5IMYeC7VOnoqovybRK75DQl20qEiOx+Ev3JfsHDIEU84wT3OOaC45AGXkjUZHd0
                CYAwETZnRbotoFW44NycPxrevrMLYGIUNyuBJfySz0/ydvbH5eKgXdxXqyFSqHTHN
                3b/O+WsA8EKFIAF34jAB2cLJyizq0L/z+WetHBblv1lq/2znlm3Av3ox459meBOey
                79sXJw6LxV7wO3Lw7KRYVbM67nLm4By2AZA0paey9DjXf6fd7pgWH6VAANqvqOynR
                aSEc/lH/BHk1unHdVvSYEBoTLjdK+W9PfpF7pe+sao30UVAoQqFB2loBgISuSn9Is
                qAuTyt5+SwgfUAyoZG4QHEJ1Kx2se8FQ+P23NsoFxwwGAfteYwCfqSHxkAjHTEWCG
                /Q5STuTP8LbpO/n8ee53AL1oZEdZ5X/JgZpc/npIVIvCTZn8ZlRcTackBHMGch5E0
                E+pHoWdaIF95PsNsU80n+Xm043arXnL/lGvrsC6u56Zkt8X6XxE1joeq9tL35hhdJ
                MXQJerYTXTgKc3XnkRvWlgEficzLUAsDe92sNq65D8BY3XbVtX0NEThPOCVZjFMX4
                3/wsYZAsu/yPOV1FOdT4c1f6EM5xY77Kn6vq8BhhMoCOUNplaLu4ft6tI7Xi/uJya
                1PpDYK8Br91EXtsr8NlJz/7xD6sjFaK6P4LfAAAAAElFTkSuQmCC`;
        this.defaultTextColor = '#FFF'; // white
        this.defaultSize = 24;
        this.fontSizeOffset = 0.45;
        this.showInitials = false;
        this.showDefaultAvatar = false;
    }
    ngOnInit() {
        this.initAll();
    }
    ngOnChanges() {
        this.init();
    }
    init() {
        switch (this.photo != null) {
            case true:
                // this.name = null;
                this.initials = null;
                this.showInitials = false;
                this.defaultAvatar = null;
                this.showDefaultAvatar = false;
                break;
            case false:
                if (this.name != null || undefined) {
                    this.initials = this.getInitials(this.name);
                    this.showInitials = true;
                    this.photo = null;
                    this.defaultAvatar = null;
                    this.showDefaultAvatar = false;
                }
                else {
                    this.name = null;
                    this.initials = null;
                    this.showInitials = false;
                    this.photo = null;
                    this.defaultAvatar = this.sanitizer.bypassSecurityTrustUrl(this.defaultAvatarImage);
                    ;
                    this.showDefaultAvatar = true;
                }
                break;
            default:
                this.name = null;
                this.initials = null;
                this.showInitials = false;
                this.photo = null;
                this.defaultAvatar = this.sanitizer.bypassSecurityTrustUrl(this.defaultAvatarImage);
                ;
                this.showDefaultAvatar = true;
                break;
        }
    }
    initAll() {
        this.init();
        this.color = this.color ? this.color : this.getColor();
        this.sizeNum = this.sizeToNum(this.size);
        this.size = `${this.sizeNum}px`;
        this.textcolor = this.textcolor ? this.textcolor : this.defaultTextColor;
        this.textFontSize = `${this.sizeNum * this.fontSizeOffset}px`;
    }
    getInitials(text) {
        const names = text.split(' ');
        let initials = names[0].substring(0, 1).toUpperCase();
        if (names.length > 1) {
            initials += names[names.length - 1].substring(0, 1).toUpperCase();
        }
        return initials.toUpperCase();
    }
    getColor() {
        // return this.defaultColors[Math.floor(Math.random() * this.defaultColors.length)]
        return '#808080';
    }
    sizeToNum(inSize) {
        switch (inSize) {
            case 'small': return 24;
            case 'medium': return 48;
            case 'large': return 72;
            case 'x-large': return 96;
            case 'ion-small': return 18;
            case 'ion-medium': return 24;
            case 'ion-large': return 32;
            default: return this.defaultSize;
        }
    }
}
HybridAvatarComponent.decorators = [
    { type: Component, args: [{
                selector: 'hybrid-avatar',
                template: `
		<div class="noselect">
		<div class="circle" [ngStyle]="{'background-color': color, 'width': size, 'height':size}">
			<img *ngIf="showDefaultAvatar" [src]="defaultAvatar">

			<img *ngIf="!showInitials" [src]="photo">
			<div class="initials" *ngIf="showInitials" [ngStyle]="{'font-size': textFontSize, 'color': textcolor}">{{initials}}
			</div>
		</div>
		</div>
  `,
                styles: [".circle{display:flex;justify-content:center;align-items:center;margin:auto}.circle,.circle img{border-radius:50%}.initials{font-weight:600}.noselect{-webkit-touch-callout:none;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}"]
            },] }
];
HybridAvatarComponent.ctorParameters = () => [
    { type: DomSanitizer }
];
HybridAvatarComponent.propDecorators = {
    name: [{ type: Input }],
    photo: [{ type: Input }],
    size: [{ type: Input }],
    color: [{ type: Input }],
    textcolor: [{ type: Input }]
};

class HybridAvatarModule {
}
HybridAvatarModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    HybridAvatarComponent
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    HybridAvatarComponent
                ]
            },] }
];

/*
 * Public API Surface of hybrid-avatar
 */

/**
 * Generated bundle index. Do not edit.
 */

export { HybridAvatarComponent, HybridAvatarModule };
//# sourceMappingURL=hybrid-avatar.js.map
